neanderthal-stick.core


ContainerInfocljprotocol

describeclj

(describe this)

Get the description map of container parameters that can be used to re-create the vector/matrix.

Get the description map of container parameters that can be used to re-create the vector/matrix.
source

createclj

(create descriptor)
(create factory descriptor)
(create factory descriptor source)

Create a matrix or a vector using factory with parameters given by the descriptor map and content data source. The source can be the data source used to read the descriptor of the structure. If the factory is nil the default factory is inferred from the entry data type.

Create a matrix or a vector using `factory` with parameters given by the `descriptor` map
and content data `source`. The `source` can be the data source used to read the `descriptor`
of the structure. If the `factory` is nil the default factory is inferred from the entry data type.
sourceraw docstring

create*cljmultimethod

Create a a structure of the given kind (internal API).

Create a a structure of the given `kind` (internal API).
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries