neanderthal-stick.internal.common


describe-commonclj

(describe-common x)
source

entry-compatible?clj

(entry-compatible? native-x y)

True iff the factory of native-x and the native factory of y can handle the same data type.

True iff the factory of `native-x` and the native factory of `y` can handle the same data type.
sourceraw docstring

entry-type-kwclj

(entry-type-kw x)

Get the (keywordized) data type name stored in x.

Get the (keywordized) data type name stored in `x`.
sourceraw docstring

layoutclj

(layout x)

Get layout ordering of x (:column or :row).

Get layout ordering of `x` (`:column` or `:row`).
sourceraw docstring

native-factory?clj

(native-factory? factory)

True iff this factory is a native (host) factory.

True iff this `factory` is a native (host) factory.
sourceraw docstring

options-omit-data?clj

(options-omit-data? options)

True if the options map specifies the data omission during save / freeze and create / thaw.

True if the `options` map specifies the data omission during save / freeze and create / thaw.
sourceraw docstring

region-optionsclj

(region-options x)
source

cljdoc builds & hosts documentation for Clojure/Script libraries