(load! data-in)(load! factory data-in)(load! factory data-in ext-options)Load a Neanderthal matrix or a vector from the data-in stream using the factory for construction.
If no factory is provided the default factory is inferred from the entry data type.
ext-options can specify load options external to the data structure itself (for example data omission).
Load a Neanderthal matrix or a vector from the `data-in` stream using the `factory` for construction. If no `factory` is provided the default factory is inferred from the entry data type. `ext-options` can specify load options external to the data structure itself (for example data omission).
(load-from-file! file-path)(load-from-file! factory file-path)(load-from-file! factory file-path ext-options)Load a Neanderthal matrix or a vector from the file path name file-path using the factory for construction.
Opens file-path with as data input stream, reads the structure and its contents, closesfile-path. If nofactoryis provided the default factory is inferred from the entry data type.ext-optionsare passed toload!`.
Load a Neanderthal matrix or a vector from the file path name `file-path` using the `factory` for construction. Opens `file-path with as data input stream, reads the structure and its contents, closes `file-path`. If no `factory` is provided the default factory is inferred from the entry data type. `ext-options` are passed to `load!`.
(save! x data-out)(save! x data-out ext-options)Save the Neanderthal matrix or the vector x to the data-out stream.
ext-options can specify save options external to the data structure itself (for example data omission).
Save the Neanderthal matrix or the vector `x` to the `data-out` stream. `ext-options` can specify save options external to the data structure itself (for example data omission).
(save-to-file! x file-path)(save-to-file! x file-path ext-options)Save the Neanderthal matrix or the vector x to the file path name file-path. Opens file-path as data output stream, writes the structure and its contents, closesfile-path.ext-optionsare passed tosave!`.
Save the Neanderthal matrix or the vector `x` to the file path name `file-path`. Opens `file-path as data output stream, writes the structure and its contents, closes `file-path`. `ext-options` are passed to `save!`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |