(entry-compatible? native-x y)True iff the factory of native-x and the native factory of y can handle the same data type.
True iff the factory of `native-x` and the native factory of `y` can handle the same data type.
(entry-type-kw x)Get the (keywordized) data type name stored in x.
Get the (keywordized) data type name stored in `x`.
(layout x)Get layout ordering of x (:column or :row).
Get layout ordering of `x` (`:column` or `:row`).
(native-factory? factory)True iff this factory is a native (host) factory.
True iff this `factory` is a native (host) factory.
(options-omit-data? options)True if the options map specifies the data omission during save / freeze and create / thaw.
True if the `options` map specifies the data omission during save / freeze and create / thaw.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |