Dynamically bound factory that is used in Neanderthal vector and matrix constructors.
Dynamically bound factory that is used in Neanderthal vector and matrix constructors.
(freeze-through-native! data-output x)Freeze x to data-output by using a temp copy in host memory if needed.
Freeze `x` to `data-output` by using a temp copy in host memory if needed.
(thaw-from-in! data-input)Thaw a previously frozen descriptor from the `data-input to a new Neanderthal structure.
Thaw a previously frozen descriptor from the `data-input to a new Neanderthal structure.
(with-real-factory factory & body)Create a bind to use the factory during Neanderthal real vector and matrix construction.
(clojurecuda/with-default
(with-open [in (DataInputStream. (io/input-stream (io/file "/tmp/my_matrix.bin")))]
(with-real-factory (cuda-double (current-context) default-stream)
(nippy/thaw-from-in! in)))
Create a bind to use the `factory` during Neanderthal real vector and matrix construction.
```
(clojurecuda/with-default
(with-open [in (DataInputStream. (io/input-stream (io/file "/tmp/my_matrix.bin")))]
(with-real-factory (cuda-double (current-context) default-stream)
(nippy/thaw-from-in! in)))
```
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |